#include <stdio.h>
#include "gdal_priv.h"


//display data array as ascii art
//key:
// * > 0 (land)
// o = 0 (usually header misinterpreted as data or land with zero elevation)
// ~ < 0 (ocean)
void print_data(float *data, int nXSize, int nYSize){
    for(int jj=nYSize-1; jj>=0; jj--){
        for(int ii=0; ii<nXSize; ii++){
	    float x=data[ii+jj*nXSize];
	    if(x>0.0) printf("*");
	    if(x<0.0) printf("~");
	    if(x==0.0) printf("o");
	}
	printf("\n");
    }
}



int main()
{
    GDALDataset  *poDataset;
    char *pszFilename = "dem.ers";

    GDALAllRegister();
    
    poDataset = (GDALDataset *) GDALOpen( pszFilename, GA_ReadOnly );
    if( poDataset == NULL )
    {
        printf( "Unable to open file\n");
	return 1;
    }

    //fetch raster band
    GDALRasterBand  *poBand;    
    poBand = poDataset->GetRasterBand(1);

    //read data
    float *data;
    int   nXSize = poBand->GetXSize();
    int   nYSize = poBand->GetYSize();

    data = (float *) CPLMalloc(sizeof(float)*nXSize*nYSize);
    poBand->RasterIO( GF_Read, 0, 0, nXSize, nYSize, 
                      data, nXSize, nYSize, GDT_Float32, 
                      0, 0 );

    print_data(data,nXSize,nYSize);

    delete poDataset;
    return 0;

}

